@@ -1,11 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mu4e-walk" "20250915.637"
+(define-package "mu4e-walk" "20251103.712"
   "Send email addresses for a walk."
-  '((emacs "29.1")
-    (mu4e  "1.12"))
+  '((emacs "29.1"))
   :url "https://codeberg.org/timmli/mu4e-walk"
-  :commit "f062152e50b6354d122a763947acc6b305dc66ef"
-  :revdesc "f062152e50b6"
+  :commit "8f5360aca1df9fa87bc9b99a32bd81422dff78b9"
+  :revdesc "8f5360aca1df"
   :keywords '("convenience" "mail")
   :authors '(("Timm Lichte" . "timm.lichte@uni-tuebingen.de"))
   :maintainers '(("Timm Lichte" . "timm.lichte@uni-tuebingen.de")))
